@@ -1,11 +1,10 @@
 """Abstraction over the data storage for the application."""
 from __future__ import annotations
 
-from . import abc, exceptions, filters, sqlalchemy, types
+from . import abc, filters, sqlalchemy, types
 
 __all__ = [
     "abc",
-    "exceptions",
     "filters",
     "sqlalchemy",
     "types",
